Crate minigrep_jondeaves

Crate minigrep_jondeaves 

Minigrep

minigrep_jondeaves is a lightweight implementation of the well known grep command.

Structs

Config

Functions

run
search
Finds all lines within a block of text that contain the query, this method is case-sensitive
search_case_insensitive
Finds all lines within a block of text that contain the query, this method is case-insensitive