Minigrep
minigrep_jondeaves is a lightweight implementation of the well known grep command.
Structs
Functions
- run
- search
- Finds all lines within a block of text that contain the query, this method is case-sensitive
- search_
case_ insensitive - Finds all lines within a block of text that contain the query, this method is case-insensitive